@@ -1,5 +1,4 @@
 import logging
-from uuid import UUID
 
 from django.http import HttpResponseBadRequest, HttpResponseForbidden, JsonResponse
 from django.views import View
@@ -31,21 +30,8 @@ class RequestAccessView(View):
         # App sends hex digest in uppercase, the web page in lower case ;)
         hashed_password = hashed_password.lower()
 
-        device_id = access_data.get('DeviceId') or access_data.get('IDT')
-        if not device_id:
-            logger.error('No "DeviceId" or "IDT" !')
-            return HttpResponseBadRequest()
-
-        try:
-            device_id = UUID(device_id)
-        except ValueError as err:
-            logger.error('IDT %r is no UUID: %s', device_id, err)
-            return HttpResponseForbidden()
-
-        device = Device.objects.filter(uuid=device_id).first()
-        if not device:
-            logger.error('Device entry not found for: %r', device_id)
-            return HttpResponseBadRequest()
+        raw_short_id = access_data.get('DeviceId') or access_data.get('IDT')
+        device = Device.objects.get_by_short_id(raw_short_id=raw_short_id)
 
         if hashed_password != device.hashed_password:
             logger.error(
@@ -57,5 +43,5 @@ class RequestAccessView(View):
             return HttpResponseForbidden()
 
         access_token = new_access_token(device=device)
-        accesstoken_reply = {'IDT': device.uuid, 'Data': access_token}
-        return JsonResponse(accesstoken_reply)
+        access_token_reply = {'IDT': device.short_id, 'Data': access_token}
+        return JsonResponse(access_token_reply)
