@@ -4,7 +4,7 @@ from pathlib import Path
 import cmd2
 from dev_shell.base_cmd2_app import DevShellBaseApp, run_cmd2_app
 from dev_shell.command_sets import DevShellBaseCommandSet
-from dev_shell.command_sets.dev_shell_commands import DevShellCommandSet as OriginDevShellCommandSet
+from dev_shell.command_sets.dev_shell_commands import DevShellCommandSet
 from dev_shell.config import DevShellConfig
 from dev_shell.utils.assertion import assert_is_dir
 from dev_shell.utils.colorful import blue, bright_yellow, print_error
@@ -144,24 +144,6 @@ class FindMyDeviceCommandSet(DevShellBaseCommandSet):
         )
 
 
-class DevShellCommandSet(OriginDevShellCommandSet):
-    def do_publish(self, statement: cmd2.Statement):
-        """
-        Publish "dev-shell" to PyPi
-        """
-        # Maybe a project that use dev-shell doesn't use poetry-publish, too!
-        # So import it here to make this dependency "optional"
-        from poetry_publish.publish import poetry_publish  # noqa
-
-        # Don't publish if test failed or code linting wrong:
-        self.do_pytest(statement=statement)
-
-        poetry_publish(
-            package_root=self.config.base_path,
-            version=self.config.version,
-        )
-
-
 class DevShellApp(DevShellBaseApp):
     pass
 
