@@ -31,7 +31,7 @@ class RunTestServerTestCase(TestCase):
 
     def test_pass_wrong_addrport(self):
         output = call_run_testserver('not-ip:no-port')
-        assert "call 'runserver' command with" in output
+        assert 'call "runserver" command with' in output
         assert (
             'CommandError: "not-ip:no-port" is not a valid port number or address:port pair.'
         ) in output
